<?php
/** 
* @desc this program will add or edit a logaholic profiles 
* for more information please read:
* http://www.logaholic.com/manual/LogaholicManual/APIDocumentationForServiceProviderEditions  
*/

class LogaholicDBProfile {

    var $site;
    var $username;
    var $logfilelocation="";
    var $trackermode="0";
    var $splitlogs="1";
    var $splitfilter="";
    var $profile_name;
    var $equivdomains="";
	var $urlparamfilter="";
	var $urlparamfiltermode="";
    
    function __construct($ProfileName = null) {
        global $config, $running_from_command_line, $db, $databasedriver, $DatabaseName;
        
        $running_from_command_line=true;
        include_once($config['path']."/common.inc.php");
        include_once($config['path']."/languages/english.php");
        
        if (!isset($ProfileName)) {
			$this->CheckVars();   
		}
    }
    
    function LogaholicDBProfile($ProfileName = null) {
        __construct($ProfileName);
    }
    
    function CheckVars() {
        global $action;
        
        $help = "Required variables:<br>\n";
        $help.= " - site (the (sub)domain to be added or deleted)<br>\n";
        $help.= " - username (the username of the account that owns this site, only required when adding profiles)<br>\n";
        $help .= "Optional variables:<br>\n";
        $help.= " - logfilelocation (if empty, Data collection method will be set to javascript basedtracking)<br>\n";
        $help.= " - splitlogs (indicates if logfilelocation is a directory or a file)<br>\n";
        $help.= " - splitfilter (keyword or regex that files in logfilelocation dir must match)<br>\n";
        $help.= " - profile_name (use this to overrule the automatic generation of a profilename from the site name)<br>\n";
        $help.= " - equivdomains (any aliases of the main domain name that point to the same site)<br>\n";
		$help.= " - urlparamfilter (comma delimited list of url params that need to be filtered)<br>\n";		
        $help.= " - urlparamfiltermode (Include or Exclude params from urlparamfilter, default Exclude)<br>\n";        
		
        if (!empty($_GET['site'])) {
            $this->site = $_GET['site'];   
        } else {
            echo $help;
            exit();    
        }
        if (!empty($_GET['username'])) {
            $this->username = $_GET['username'];        
        } else {
            if ($action=="addprofile") {
                echo $help;
                exit();     
            } else {
                $this->username="";
            }    
        }
        if (!empty($_GET['logfilelocation'])) {
            $this->logfilelocation = $_GET['logfilelocation'];   
        } else {
            $this->trackermode="1";    
        }
        if (isset($_GET['splitlogs'])) { 
            $this->splitlogs=$_GET['splitlogs'];
        }
        if (!empty($_GET['splitfilter'])) { 
            $this->splitfilter=$_GET['splitfilter'];
        }
        if (!empty($_GET['profile_name'])) { 
            $this->profile_name=$_GET['profile_name'];
        }
        if (!empty($_GET['equivdomains'])) { 
            $this->equivdomains=$_GET['equivdomains'];
        }
		if (!empty($_GET['urlparamfilter'])) { 
            $this->urlparamfilter=$_GET['urlparamfilter'];
        }
		if (!empty($_GET['urlparamfiltermode'])) { 
            $this->urlparamfiltermode=$_GET['urlparamfiltermode'];
        }		
        if (substr($this->site,0,4)=="http") {
            echo "The site variable should not contain http prefix! <br><br>\n\n";
            echo $help;
            exit();                
        }
		
		if (empty($this->profile_name)) {
            $this->profile_name = $this->siteToProfilename($this->site);    
        }
		
        return;
    }
	
	function EditProfile() {
		global $db, $databasedriver;
		
        if ($this->profile_name!="") {
            $p = $this->profile_name;
        } else {
            $p = $this->siteToProfilename($this->site);
        }
		
		# set up the profile object
		$profile = new SiteProfile($p);
		
		foreach($_GET as $key => $val) {
			switch($key) {
				case "api_password";
				case "action";
				case "username";
				case "site";
					break;
				default:
					$profile->{$key} = $val;
			}
		}
		
        $profile->Save();
	}
    
    function AddProfile() {
        global $db, $databasedriver;
        
        # set up the new profile
        $profile = new SiteProfile();
        if ($this->profile_name!="") {
            $profile->profilename = $this->profile_name;  
        } else {
            $profile->profilename = $this->siteToProfilename($this->site);    
        }
        if ($profile->profilename=="") {
            echo "Invalid profilename: $profile->profilename\n";
            exit();
        }
        if ($this->profileExists($profile->profilename)==true) {
            echo "Profile '$profile->profilename' already exists\n";
            $this->AddProfiletoUser($profile->profilename);
            exit();    
        }
                  
        $profile->confdomain = $this->site;                
        $profile->equivdomains = $this->equivdomains;
		$profile->urlparamfilter = $this->urlparamfilter;
		if (!empty($this->urlparamfiltermode)) {
			$profile->urlparamfiltermode = $this->urlparamfiltermode;
		}
                                   
        if ($this->trackermode==1) {
            $profile->trackermode=1;
            $profile->logfilefullpath = "";    
            $profile->splitlogs = 0;
            $profile->visitoridentmethod = 3;    
        } else {
            $profile->logfilefullpath = $this->logfilelocation;    
            $profile->splitlogs = $this->splitlogs;
            $profile->splitfilter = $this->splitfilter;
            $profile->trackermode=0;
        }
        
        $profile->Save();
        createDataTable($profile);
        
        # now add the new profile to the profile list in the user table
        $this->AddProfiletoUser($profile->profilename);
        
        echo "Success: Created profile $profile->profilename for $this->site \n";        
    }
    
    function DeleteProfile() {
        global $db;
        if ($this->profile_name!="") {
            $p = $this->profile_name;  
        } else {
            $p = $this->siteToProfilename($this->site);    
        }
        $profile = new SiteProfile($p);
        
        if ($profile->profileid=="") {
            die ("An error occurred: Profile not found");    
        }
        
        # first, delete the profile from the profiles table
        $query = "Delete from ".TBL_PROFILES." where profileid = ".$profile->profileid;
        @$db->Execute($query) or die("An error occurred: " . $db->ErrorMsg());
        
        # next, delete profile data from the globalsettings table
        deleteProfileData($profile->profilename);
        
        # now, delete the profile tables in the db  
        deleteDataTable($profile);
        
        # finally, remove the profile from the users profile lists
        DeleteProfileFromUsers($profile->profilename);       
        
        echo "Success: Deleted profile for $this->site<br>\n";
        
    }
    
    private function siteToProfilename($site) {
        return preg_replace('/[^a-z0-9]/', '', $site);    
    }
    
    function profileExists($name) {
        global $db;
        
        $q = $db->Execute("select profileid from ".TBL_PROFILES." where profilename=\"$name\"");
        if ($q->NumRows() > 0) {
            return true;    
        } else {
            return false;    
        }
            
    }
	
	function GetProfileInfo(){
		$profile = new Siteprofile($this->profile_name);
		$profile_dump = array();
		foreach($profile as $k => $v){
			$profile_dump[$k] = $v;
		}
		echo serialize($profile_dump);
	}
    
    function AddProfiletoUser($profile_name) {
        # first, get the list of profiles for this user
        $pl = getProfileList($this->username);
        if ($pl===false) {
			return false;
		}
		if ($pl!="") {
            $pl = explode(",",$pl);
            if (!in_array($profile_name,$pl)) {
                # add it
                $pl[] = $profile_name;            
            }
            saveProfileList($this->username,implode(",",$pl));
        } else {
            $pl=$profile_name;
            saveProfileList($this->username,$pl);    
        }      
    } 
	
	function getProfileDBSize($profile_name) {
		global $db,$DatabaseName;
        # first, get the tablename for this profiles
		$profile = new SiteProfile($profile_name);
		$query= "SELECT sum( data_length + index_length ) \"bytes\" ";
        $query .= "FROM information_schema.TABLES where table_schema='$DatabaseName' and (table_name='$profile->tablename' or table_name like '$profile->tablename\_%')";
		$q = $db->Execute($query);
		$data = $q->FetchRow();
		return $data[0];
	}
	
	function includeBackup() {
		global $db;
		
		$q = $db->Execute("select Value from _logaholic_GlobalSettings where Profile='$this->profile_name' and Name = '".$this->profile_name.".includebackup'");
		if ($data = $q->FetchRow()) {
			if ($data['Value']==1) {
				echo "true";
				return true;
			} else {
				echo "false";
				return false;
			}
		}
		echo "false";
		return false;
	}
			
}
?>